@@ -2,7 +2,7 @@ package Net::AMQP::RabbitMQ;
 use strict;
 use warnings;
 
-our $VERSION = '0.006000';
+our $VERSION = '0.006002';
 
 use XSLoader;
 XSLoader::load "Net::AMQP::RabbitMQ", $VERSION;
@@ -43,18 +43,16 @@ Error handling in this module is primarily achieve by Perl_croak (die). You
 should be making good use of eval around these methods to ensure that you
 appropriately catch the errors.
 
-=head2 Methods
+=head1 METHODS
 
 All methods, unless specifically stated, return nothing on success
 and die on failure.
 
-=over 4
-
-=item new()
+=head2 new()
 
 Creates a new Net::AMQP::RabbitMQ object.
 
-=item connect( $hostname, $options )
+=head2 connect( $hostname, $options )
 
 C<$hostname> is the host to which a connection will be attempted.
 
@@ -71,27 +69,27 @@ C<$options> is an optional hash respecting the following keys:
        timeout => $seconds      #default undef (no timeout)
      }
 
-=item disconnect()
+=head2 disconnect()
 
 Causes the connection to RabbitMQ to be torn down.
 
-=item is_connected()
+=head2 is_connected()
 
 Returns true if a valid socket connection appears to exist, false otherwise.
 
-=item channel_open($channel)
+=head2 channel_open($channel)
 
 C<$channel> is a positive integer describing the channel you which to open.
 
-=item channel_close($channel)
+=head2 channel_close($channel)
 
 C<$channel> is a positive integer describing the channel you which to close.
 
-=item get_channel_max()
+=head2 get_channel_max()
 
 Returns the maximum allowed channel number.
 
-=item exchange_declare($channel, $exchange, $options)
+=head2 exchange_declare($channel, $exchange, $options)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
@@ -106,7 +104,7 @@ C<$options> is an optional hash respecting the following keys:
        auto_delete => $boolean, #default 1
      }
 
-=item exchange_delete($channel, $exchange, $options)
+=head2 exchange_delete($channel, $exchange, $options)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
@@ -119,7 +117,7 @@ C<$options> is an optional hash respecting the following keys:
        nowait => $boolean,      #default 0
      }
 
-=item queue_declare($channel, $queuename, $options, $arguments)
+=head2 queue_declare($channel, $queuename, $options, $arguments)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
@@ -140,7 +138,7 @@ C<$arguments> is an optional hash which will be passed to the server
 when the queue is created.  This can be used for creating mirrored
 queues by using the x-ha-policy header.
 
-In scalar context, this method returns the queuename delcared
+In scalar context, this method returns the queuename declared
 (important for retrieving the autogenerated queuename in the
 event that one was requested).
 
@@ -148,7 +146,7 @@ In array context, this method returns three items: queuename,
 the number of message waiting on the queue, and the number
 of consumers bound to the queue.
 
-=item queue_bind($channel, $queuename, $exchange, $routing_key, $arguments)
+=head2 queue_bind($channel, $queuename, $exchange, $routing_key, $arguments)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
@@ -160,7 +158,7 @@ C<$arguments> is an optional hash which will be passed to the server.  When
 binding to an exchange of type C<headers>, this can be used to only receive
 messages with the supplied header values.
 
-=item queue_unbind($channel, $queuename, $exchange, $routing_key, $arguments)
+=head2 queue_unbind($channel, $queuename, $exchange, $routing_key, $arguments)
 
 This is like the C<queue_bind> with respect to arguments.  This command unbinds
 the queue from the exchange.  The C<$routing_key> and C<$arguments> must match
@@ -168,20 +166,20 @@ the values supplied when the binding was created.
 
 If this fails, you must reopen the channel
 
-=item queue_delete($channel, $queuename, $options)
+=head2 queue_delete($channel, $queuename, $options)
 
 Deletes the queue
 
 C<$options> is an optional hash respecting the following keys:
 
-    {
+     {
        if_unused    => $boolean,     #default 1
        if_empty     => $boolean,     #default 1
      }
 
 If this fails, you must reopen the channel
 
-=item publish($channel, $routing_key, $body, $options, $props)
+=head2 publish($channel, $routing_key, $body, $options, $props)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
@@ -198,6 +196,7 @@ C<$options> is an optional hash respecting the following keys:
      }
 
 C<$props> is an optional hash (the AMQP 'props') respecting the following keys:
+
      {
        content_type => $string,
        content_encoding => $string,
@@ -213,7 +212,7 @@ C<$props> is an optional hash (the AMQP 'props') respecting the following keys:
        timestamp => $integer,
      }
 
-=item consume($channel, $queuename, $options)
+=head2 consume($channel, $queuename, $options)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
@@ -233,7 +232,7 @@ The consumer_tag is returned.  This command does B<not> return AMQP
 frames, it simply notifies RabbitMQ that messages for this queue should
 be delivered down the specified channel.
 
-=item recv()
+=head2 recv()
 
 This command receives and reconstructs AMQP frames and returns a hash
 containing the following information:
@@ -248,6 +247,7 @@ containing the following information:
      }
 
 C<$props> is the hash sent by publish()  respecting the following keys:
+
      {
        content_type => $string,
        content_encoding => $string,
@@ -263,17 +263,11 @@ C<$props> is the hash sent by publish()  respecting the following keys:
        timestamp => $integer,
      }
 
-=item get($channel, $queuename, $options)
-
-C<$channel> is a channel that has been opened with C<channel_open>.
-
-C<$queuename> is the name of the queue from which we'd like to consume.
-
-C<$options> is an optional hash respecting the following keys:
+=head2 get($channel, $queuename, $options)
 
 This command runs an amqp_basic_get which returns undef immediately
-if no messages are available on the queue and returns a has as follows
-if a message is available.
+if no messages are available on the queue and returns a hash as follows
+if a message is available:
 
      {
        body => 'Magic Transient Payload', # the reconstructed body
@@ -285,7 +279,17 @@ if a message is available.
        message_count => 0,                # message count
      }
 
-=item ack($channel, $delivery_tag, $multiple = 0)
+C<$channel> is a channel that has been opened with C<channel_open>.
+
+C<$queuename> is the name of the queue from which we'd like to consume.
+
+C<$options> is an optional hash respecting the following keys:
+
+     {
+       no_ack => $boolean,  #default 1
+     }
+
+=head2 ack($channel, $delivery_tag, $multiple = 0)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
@@ -294,13 +298,13 @@ C<recv> method.
 
 C<$multiple> specifies if multiple are to be acknowledged at once.
 
-=item purge($channel, $queuename)
+=head2 purge($channel, $queuename)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$queuename> is the queue to be purged.
 
-=item reject($channel, $delivery_tag, $requeue = 0)
+=head2 reject($channel, $delivery_tag, $requeue = 0)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
@@ -309,26 +313,25 @@ C<recv> method.
 
 C<$requeue> specifies if the message should be requeued.
 
-
-=item tx_select($channel)
+=head2 tx_select($channel)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 Start a server-side (tx) transaction over $channel.
 
-=item tx_commit($channel)
+=head2 tx_commit($channel)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 Commit a server-side (tx) transaction over $channel.
 
-=item tx_rollback($channel)
+=head2 tx_rollback($channel)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 Rollback a server-side (tx) transaction over $channel.
 
-=item basic_qos($channel, $options)
+=head2 basic_qos($channel, $options)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
@@ -342,14 +345,12 @@ C<$options> is an optional hash respecting the following keys:
 
 Set quality of service flags on the current $channel.
 
-=item hearbeat()
+=head2 hearbeat()
 
 Send a hearbeat frame.  If you've connected with a heartbeat parameter,
 you must send a heartbeat periodically matching connection parameter or
 the server may snip the connection.
 
-=back
-
 =head1 WARNING AND ERROR MESSAGES
 
 =head2 Fatal Errors
